CSS_PROPERTIES = (
    # Layout Properties
    "display",
    "position",
    "top",
    "right",
    "bottom",
    "left",
    "float",
    "clear",
    "z-index",
    "overflow",
    "overflow-x",
    "overflow-y",
    "clip",
    "visibility",
    # Box Model
    "width",
    "min-width",
    "max-width",
    "height",
    "min-height",
    "max-height",
    "margin",
    "margin-top",
    "margin-right",
    "margin-bottom",
    "margin-left",
    "padding",
    "padding-top",
    "padding-right",
    "padding-bottom",
    "padding-left",
    "box-sizing",
    # Border
    "border",
    "border-width",
    "border-style",
    "border-color",
    "border-top",
    "border-top-width",
    "border-top-style",
    "border-top-color",
    "border-right",
    "border-right-width",
    "border-right-style",
    "border-right-color",
    "border-bottom",
    "border-bottom-width",
    "border-bottom-style",
    "border-bottom-color",
    "border-left",
    "border-left-width",
    "border-left-style",
    "border-left-color",
    "border-radius",
    "border-top-left-radius",
    "border-top-right-radius",
    "border-bottom-right-radius",
    "border-bottom-left-radius",
    "border-image",
    "border-image-source",
    "border-image-slice",
    "border-image-width",
    "border-image-outset",
    "border-image-repeat",
    "border-collapse",
    "border-spacing",
    # Background
    "background",
    "background-color",
    "background-image",
    "background-repeat",
    "background-attachment",
    "background-position",
    "background-position-x",
    "background-position-y",
    "background-size",
    "background-clip",
    "background-origin",
    "background-blend-mode",
    # Typography
    "color",
    "font",
    "font-family",
    "font-size",
    "font-weight",
    "font-style",
    "font-variant",
    "font-stretch",
    "line-height",
    "letter-spacing",
    "word-spacing",
    "text-align",
    "text-align-last",
    "text-decoration",
    "text-decoration-line",
    "text-decoration-color",
    "text-decoration-style",
    "text-decoration-thickness",
    "text-indent",
    "text-transform",
    "text-shadow",
    "text-overflow",
    "text-wrap",
    "white-space",
    "word-break",
    "word-wrap",
    "overflow-wrap",
    "hyphens",
    "direction",
    "unicode-bidi",
    "writing-mode",
    "vertical-align",
    # Lists
    "list-style",
    "list-style-type",
    "list-style-position",
    "list-style-image",
    # Tables
    "caption-side",
    "empty-cells",
    "table-layout",
    # Flexbox
    "flex",
    "flex-direction",
    "flex-wrap",
    "flex-flow",
    "justify-content",
    "align-items",
    "align-content",
    "align-self",
    "flex-grow",
    "flex-shrink",
    "flex-basis",
    "order",
    "gap",
    "row-gap",
    "column-gap",
    # Grid
    "grid",
    "grid-template",
    "grid-template-columns",
    "grid-template-rows",
    "grid-template-areas",
    "grid-auto-columns",
    "grid-auto-rows",
    "grid-auto-flow",
    "grid-column",
    "grid-column-start",
    "grid-column-end",
    "grid-row",
    "grid-row-start",
    "grid-row-end",
    "grid-area",
    "place-items",
    "place-content",
    "place-self",
    # Transform & Animation
    "transform",
    "transform-origin",
    "transform-style",
    "perspective",
    "perspective-origin",
    "backface-visibility",
    "transition",
    "transition-property",
    "transition-duration",
    "transition-timing-function",
    "transition-delay",
    "animation",
    "animation-name",
    "animation-duration",
    "animation-timing-function",
    "animation-delay",
    "animation-iteration-count",
    "animation-direction",
    "animation-fill-mode",
    "animation-play-state",
    # Effects
    "opacity",
    "filter",
    "backdrop-filter",
    "box-shadow",
    "mix-blend-mode",
    "isolation",
    # Multi-column Layout
    "columns",
    "column-count",
    "column-width",
    "column-gap",
    "column-rule",
    "column-rule-width",
    "column-rule-style",
    "column-rule-color",
    "column-span",
    "column-fill",
    "break-before",
    "break-after",
    "break-inside",
    # User Interface
    "cursor",
    "outline",
    "outline-width",
    "outline-style",
    "outline-color",
    "outline-offset",
    "resize",
    "user-select",
    "pointer-events",
    "caret-color",
    "scroll-behavior",
    "scroll-margin",
    "scroll-padding",
    "scroll-snap-type",
    "scroll-snap-align",
    "scroll-snap-stop",
    "touch-action",
    # Content
    "content",
    "quotes",
    "counter-reset",
    "counter-increment",
    # Masking & Clipping
    "clip-path",
    "mask",
    "mask-image",
    "mask-mode",
    "mask-repeat",
    "mask-position",
    "mask-clip",
    "mask-origin",
    "mask-size",
    "mask-composite",
    # Shapes
    "shape-outside",
    "shape-margin",
    "shape-image-threshold",
    # Object Fit
    "object-fit",
    "object-position",
    # Aspect Ratio
    "aspect-ratio",
    # Appearance
    "appearance",
    # Will Change
    "will-change",
    # Contain
    "contain",
    "content-visibility",
    # Inset
    "inset",
    "inset-block",
    "inset-block-start",
    "inset-block-end",
    "inset-inline",
    "inset-inline-start",
    "inset-inline-end",
    # Logical Properties
    "block-size",
    "inline-size",
    "min-block-size",
    "min-inline-size",
    "max-block-size",
    "max-inline-size",
    "margin-block",
    "margin-block-start",
    "margin-block-end",
    "margin-inline",
    "margin-inline-start",
    "margin-inline-end",
    "padding-block",
    "padding-block-start",
    "padding-block-end",
    "padding-inline",
    "padding-inline-start",
    "padding-inline-end",
    "border-block",
    "border-block-width",
    "border-block-style",
    "border-block-color",
    "border-block-start",
    "border-block-start-width",
    "border-block-start-style",
    "border-block-start-color",
    "border-block-end",
    "border-block-end-width",
    "border-block-end-style",
    "border-block-end-color",
    "border-inline",
    "border-inline-width",
    "border-inline-style",
    "border-inline-color",
    "border-inline-start",
    "border-inline-start-width",
    "border-inline-start-style",
    "border-inline-start-color",
    "border-inline-end",
    "border-inline-end-width",
    "border-inline-end-style",
    "border-inline-end-color",
    "border-start-start-radius",
    "border-start-end-radius",
    "border-end-start-radius",
    "border-end-end-radius",
    # Overscroll
    "overscroll-behavior",
    "overscroll-behavior-x",
    "overscroll-behavior-y",
    "overscroll-behavior-inline",
    "overscroll-behavior-block",
    # Accent Color
    "accent-color",
    # Print
    "page-break-before",
    "page-break-after",
    "page-break-inside",
    "orphans",
    "widows",
)
